%define anolis_release 2
%global pypi_name dnspython

%bcond_with trio
%bcond_with curio
%bcond_with doh

Name:           python-dns
Version:        2.2.1
Release:        %{anolis_release}%{?dist}
Summary:        DNS toolkit for Python

# The entire package is licensed with both licenses, see LICENSE file
License:        ISC and MIT
URL:            http://www.dnspython.org

Source0:        https://github.com/rthalley/%{pypi_name}/archive/v%{version}/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-pytest

%global _description %{expand:
dnspython is a DNS toolkit for Python. It supports almost all record
types. It can be used for queries, zone transfers, and dynamic
updates. It supports TSIG authenticated messages and EDNS0.

dnspython provides both high and low level access to DNS. The high
level classes perform queries for data of a given name, type, and
class, and return an answer set. The low level classes allow direct
manipulation of DNS zones, messages, names, and records.
}

%description %_description
%package -n python3-dns
Summary:        %{summary}

%description -n python3-dns %_description

%generate_buildrequires
%pyproject_buildrequires -r %{?with_trio:-x trio} %{?with_curio:-x curio} %{?with_doh:-x doh}

%prep
%autosetup -p1 -n %{pypi_name}-%{version}
# Update trio from 0.20 to 0.21
sed -i "s/\(trio = {version=\">=0.14,<0.\)20\(\", optional=true}\)/\121\2/" pyproject.toml
# Update cryptography from 37.0 to 38.0
sed -i "s/\(cryptography = {version=\">=2.6,<\)37.0\(\", optional=true}\)/\138.0\2/" pyproject.toml

# strip exec permissions so that we don't pick up dependencies from docs
find examples -type f | xargs chmod a-x

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files dns

%check
%pytest

%files -n python3-dns -f %{pyproject_files}
%license LICENSE
%doc README.md examples
%pycached %exclude %{python3_sitelib}/dns/_trio_backend.py
%pycached %exclude %{python3_sitelib}/dns/_curio_backend.py

%pyproject_extras_subpkg -n python3-dns dnssec idna

%if %{with doh}
%pyproject_extras_subpkg -n python3-dns doh
%endif

%if %{with trio}
%pyproject_extras_subpkg -n python3-dns trio
%pycached %{python3_sitelib}/dns/_trio_backend.py
%endif

%if %{with curio}
%pyproject_extras_subpkg -n python3-dns curio
%pycached %{python3_sitelib}/dns/_curio_backend.py
%endif

%changelog
* Sat Dec 17 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.2.1-2
- rebuild with python-cryptography update

* Fri Jul 15 2022 happy_orange <songnannan@linux.alibaba.com> - 2.2.1-1
- Init pacakge from upstream
